@@ -179,36 +179,56 @@ checkerboard <- function(n = 8, ratio = 4){
   res
 }
 
-.check_column_names <- function(df){
-  if(sum(c("x", "y", "dx", "dy", "z") %in% names(df)) != 5) 
-    stop("column names 'x', 'y', 'dx', 'dy', and 'z' are reqired")
+is.recmap <- function(object){
+  if(sum(c("x", "y", "dx", "dy", "z") %in% names(object)) != 5) {
+    message("column names 'x', 'y', 'dx', 'dy', and 'z' are required.")
+    return (FALSE)
+  }
   
-  if (!is.numeric(df$x))
-    stop("x is not numeric.")
+  if (!is.numeric(object$x)){
+    message("x is not numeric.")
+    return(FALSE)
+  }
   
-  if (!is.numeric(df$y))
-    stop("y is not numeric.")
+  if (!is.numeric(object$y)) {
+    message("y is not numeric.")
+    return(FALSE)
+  }
   
-  if (!is.numeric(df$dx))
-    stop("dx is not numeric.")
+  if (!is.numeric(object$dx)){
+    message("dx is not numeric.")
+    return(FALSE)
+  }
   
-  if (!is.numeric(df$dy))
-    stop("dy is not numeric.")
+  if (!is.numeric(object$dy)){
+    message("dy is not numeric.")
+    return(FALSE)
+  }
   
-  if (!is.numeric(df$z))
-    stop("z is not numeric.")
+  if (!is.numeric(object$z)){
+    message("z is not numeric.")
+    return(FALSE)
+  }
   
-  if (sum(df$dx < 0) != 0)
-    stop('dx values have to be greater than 0.')
+  if (sum(object$dx < 0) != 0) {
+    message('dx values have to be greater than 0.')
+    return(FALSE)
+  }
   
-  if (sum(df$dy < 0) != 0)
-    stop('dy values have to be greater than 0.')
+  if (sum(object$dy < 0) != 0){
+    message('dy values have to be greater than 0.')
+    return(FALSE)
+  }
   
-  if (sum(df$z <= 0) != 0)
-    stop('z values have to be greater equal than 0.')
+  if (sum(object$z <= 0) != 0){
+    message('z values have to be greater equal than 0.')
+    return(FALSE)
+  }
   
-  if (nrow(df) < 2) 
-    stop('requires at least two map regions.')
+  if (nrow(object) < 2) {
+    message('requires at least two map regions.')
+    return(FALSE)
+  }
   
   
   return (TRUE)
@@ -217,7 +237,7 @@ checkerboard <- function(n = 8, ratio = 4){
 
 recmap <- function(V, E = data.frame(u=integer(), v=integer())) {
 
-  if (.check_column_names(V)){
+  if (is.recmap(V)){
     res <- recmap_(V, E)
   
     class(res) = c('recmap', class(res))
@@ -225,11 +245,16 @@ recmap <- function(V, E = data.frame(u=integer(), v=integer())) {
   }
 }
 
+
+as.SpatialPolygonsDataFrame <- function (x, ...) {
+	    UseMethod("as.SpatialPolygonsDataFrame", x)
+}
+
 # requires https://CRAN.R-project.org/package=sp 
-recmap2sp <- function(rm, df=NULL){
-  
-  SpP <- SpatialPolygons(lapply(1:nrow(rm), function(i){
-    r <- rm[i, ]
+as.SpatialPolygonsDataFrame.recmap <- function(x, df = NULL, ...){
+  if (is.recmap(x)){
+  SpP <- SpatialPolygons(lapply(1:nrow(x), function(i){
+    r <- x[i, ]
     Sr <- Polygon(cbind(c(r$x - r$dx, 
                           r$x - r$dx, 
                           r$x + r$dx, 
@@ -244,14 +269,23 @@ recmap2sp <- function(rm, df=NULL){
   
   if (is.null(df)){
     return(SpatialPolygonsDataFrame(SpP, 
-                                    data.frame(z = rm$z, 
-                                               row.names = rm$name)))}
+                                    data.frame(z = x$z, 
+                                               row.names = x$name)))}
   
-  SpatialPolygonsDataFrame(SpP, df)
+  return(SpatialPolygonsDataFrame(SpP, df))
+}
+
+message("recmap2sp failed.")
+
+NULL
 }
 
 
-sp2recmap <- function(X){
+as.recmap <- function(X){
+	UseMethod("as.recmap", X)
+}
+
+as.recmap.SpatialPolygonsDataFrame <- function(X){
   
   if (class(X) == "SpatialPolygonsDataFrame"){
     n <- length(X@polygons)
@@ -270,18 +304,25 @@ sp2recmap <- function(X){
         dx <- 0.5 * (x.max - x.min)
         dy <- 0.5 * (y.max - y.min)
         
-        data.frame(x=x.min + dx, y = y.min + dy, dx=dx, dy=dy, name=p@ID)
+        data.frame(x = x.min + dx, y = y.min + dy, dx = dx, dy = dy, name=p@ID)
       }))
       
     }))
     
    df <- cbind(df, X@data) 
-   class(df) <- c('recmap', class(df))
-  return(df)
+
+   if (is.recmap(df)){
+  	class(df) <- c('recmap', class(df))
+   	return(df)
+   } else if (!'z' %in% names(df)){
+	   warning("Can not find 'z' column name in data.frame. Define 'z' and continue." )
+   }
+   return(df)
+
   }else{
-    message('requires a "SpatialPolygonsDataFrame" class as argument')
-    return (NULL)
+    message('requires a "SpatialPolygonsDataFrame" class as argument.')
   }
+    return (NULL)
 
 }
 
@@ -299,7 +340,7 @@ sp2recmap <- function(X){
 
 .compute_topology_error <- function(x){
   
-  if (sum(x$topology.error == 100)>0)
+  if (sum(x$topology.error == 100) > 0)
     return(Inf)
   
   sum(x$topology.error) 
@@ -311,8 +352,12 @@ sp2recmap <- function(X){
 }
 
 summary.recmap <- function(object, ...) {
+
   x <- object
-  if (.check_column_names(x)){
+
+  if (!is.recmap(x)){ return (NULL) }
+
+  if (is.recmap(x)){
     
     nRegions <- nrow(x)
     errorArea <- round(.compute_area_error(x), 2)
@@ -348,18 +393,17 @@ summary.recmap <- function(object, ...) {
 }
 
 plot.recmap <- function(x, col='#00000011', col.text = 'grey', border = 'darkgreen', ...){
-#  col <- '#00000011'
-#  col.text <- 'grey'
+
+  if (!is.recmap(x)){ return (NULL) }
+
   label.text <- TRUE
   S <- x
-  try (if(sum(c("x", "y", "dx", "dy") %in% names(S)) != 4) 
-    stop("column names 'x', 'y', 'dx', 'dy', and 'z' are reqired"))
   
   plot(S$x, S$y, 
        xlim = c(min(S$x - S$dx), max(S$x + S$dx)), 
        ylim = c(min(S$y - S$dy), max(S$y + S$dy)), 
        type = 'n', 
-       asp=1,
+       asp = 1,
        xlab = '',
        ylab = '',
        axes = FALSE, ...)
@@ -499,7 +543,6 @@ plot.recmapGRASP <- function(x, ...){
 
 summary.recmapGA <- function(object, ...){
   cat("summary of class recmapGA:\n")
-	
   cat("summary of the GA:\n")
   print(summary.ga(object$GA))
   
